bayespy.inference.vmp.nodes.poisson.PoissonDistribution.compute_moments_and_cgf
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonDistribution.compute_moments_and_cgf